Shytoshi Kusama™ (@ShytoshiKusama) | nitter
Description: Enjoying the Summer of #Shibarium.

Shytoshi Kusama™
@ShytoshiKusama

Enjoying the Summer of #Shibarium.

Denham Springs, LA
Joined January 2021

- Tweets 6,593
- Following 2,319
- Followers 919,945
- Likes 6,870

454 Photos and videos
454 Photos and videos

- Tweets
- Tweets & Replies
- Media
- Search

Pinned Tweet
Shytoshi Kusama™
@ShytoshiKusama
Jul 6
拝啓 初蝉の候 シバアーミーにおかれましては益々のご健勝のこと心よりお慶び申し上げます。 さて･･････blog.shibaswap.com/mo-sui-si… 略儀ながらブログにてお知らせいたします。 酷暑が続きますが、くれぐれも体調を崩されませぬよう、ご自愛ください。

## Shiba Inu Official Blog

Welcome to the Official Announcements Blog!

blog.shib.io
430
1,064
85
3,503
Shytoshi Kusama™
@ShytoshiKusama
Jul 14
Ping @garethemery ...
514
29
1,912
GIF
Shytoshi Kusama™
@ShytoshiKusama
Jul 14
#SHIBARMY #Shibarium
Blockchain Futurist Conference
@Futurist_conf
Jul 14
📢 @Shibtoken is an Official Title Sponsor of Blockchain Futurist Conference 📢 They're bringing the power of a decentralized currency to millions across the globe 🚀 👀 Catch them at #Futurist23 🗓️ August 15-16, 2023 📍 Toronto, Canada Tickets ➡️ FuturistConference.com 🌟
871
35
2,653
GIF
Shytoshi Kusama™
@ShytoshiKusama
Jul 13
As the #summerofshibarium continues we are proud to introduce new branding for Shib.io and other #SHIBARMY websites! Give it a look! #WOOF
1,537
91
4,244
Shytoshi Kusama™ retweeted
Shibacals Collaboration Studio @shibacals
Jul 12
🧑‍🔧Update : 1st Set of Finalist Announced Tmr🧑‍🔧 📢Special Giveaway📢 Giving away another two Prototypes of Shiba Inu Hoodies on Champion. 1⃣ Follow @shibacals 2⃣ Retweet 3⃣ Tag 3 frens Join our pre-sale list shibacals.com/shiba-on-champ… #SummerOfShibarium
231
449
28
1,030
Shytoshi Kusama™
@ShytoshiKusama
Jul 11
LOVE IT!!!! #SHIBARMY
ROCK'N Vodka
@rocknvodkas
Jul 10
Steve Parrott is proudly wearing a 1-of-2 Shiba Inu x ROCK'N Vodka apparel collectible utilizing the new Shibacals.com NFC technology on a Champion hoodie. @sparrpoker99 is now in the top 7% of the 10,000 entrants, with only 1517 players remaining in the World Series of Poker. Steve is currently playing Day 4 of the WSOP! The stakes are even higher as Steve advances as he now holds 339,000! This event is being televised on both CBS Sports Network and PokerGo, so tune in and root for Steve who’s representing Shiba Inu and ROCK’N Vodka! @LucieSHIB @ShytoshiKusama @shibacals @Shibtoken #rocknvodka #shib #shibacals
195
825
15
3,042
Shytoshi Kusama™ retweeted
柴犬チャーミー @shiba_charmy
Jun 27
うちのかわいいアザラシたち🦭 #柴犬
63
1,282
22
7,978
Shytoshi Kusama™ retweeted
Shibarmy Scam Alerts
@susbarium
Jun 27
🚨SHIBARMY WARNING:🚨 Impersonator account , please report so we can keep the world safe Keep safe shibarmy
43
166
3
648
Shytoshi Kusama™
@ShytoshiKusama
Jun 29
#wen is so last year. The real question is... #WHERE? #SHIBARMY #SHIBARIUM #SHIBOSHIS #SHIBAETERNITY #MVSHIB #SHIBACALS #WELLY #UNIFICATION #BADIDEAI #SEEYOUTHERE
801
1,867
137
5,467
0
Shytoshi Kusama™
@ShytoshiKusama
Jun 28
أهنئ عيد الأضحى للعالم الإسلامي بأسره.
556
52
2,398
Load more